@@ -3,10 +3,7 @@ from io import BytesIO
 import logging
 import os
 import stat
-try:
-    from unittest import SkipTest
-except ImportError:
-    from unittest2 import SkipTest
+from unittest import SkipTest
 import uuid
 
 import git
@@ -63,7 +60,7 @@ class UpdateProgress(RemoteProgress):
     CLONE, FETCH, UPDWKTREE = [1 << x for x in range(RemoteProgress._num_op_codes, RemoteProgress._num_op_codes + 3)]
     _num_op_codes = RemoteProgress._num_op_codes + 3
 
-    __slots__ = tuple()
+    __slots__ = ()
 
 
 BEGIN = UpdateProgress.BEGIN
@@ -142,7 +139,7 @@ class Submodule(IndexObject, Iterable, Traversable):
         try:
             return type(self).list_items(item.module())
         except InvalidGitRepositoryError:
-            return list()
+            return []
         # END handle intermediate items
 
     @classmethod
@@ -278,7 +275,7 @@ class Submodule(IndexObject, Iterable, Traversable):
             if not path.startswith(working_tree_linux):
                 raise ValueError("Submodule checkout path '%s' needs to be within the parents repository at '%s'"
                                  % (working_tree_linux, path))
-            path = path[len(working_tree_linux) + 1:]
+            path = path[len(working_tree_linux.rstrip('/')) + 1:]
             if not path:
                 raise ValueError("Absolute submodule path '%s' didn't yield a valid relative path" % path)
             # end verify converted relative path makes sense
@@ -358,7 +355,9 @@ class Submodule(IndexObject, Iterable, Traversable):
         if sm.exists():
             # reretrieve submodule from tree
             try:
-                return repo.head.commit.tree[path]
+                sm = repo.head.commit.tree[path]
+                sm._name = name
+                return sm
             except KeyError:
                 # could only be in index
                 index = repo.index
@@ -1161,7 +1160,7 @@ class Submodule(IndexObject, Iterable, Traversable):
         try:
             parser = cls._config_parser(repo, pc, read_only=True)
         except IOError:
-            raise StopIteration
+            return
         # END handle empty iterator
 
         rt = pc.tree                                # root tree
@@ -1185,8 +1184,9 @@ class Submodule(IndexObject, Iterable, Traversable):
                     entry = index.entries[index.entry_key(p, 0)]
                     sm = Submodule(repo, entry.binsha, entry.mode, entry.path)
                 except KeyError:
-                    raise InvalidGitRepositoryError(
-                        "Gitmodule path %r did not exist in revision of parent commit %s" % (p, parent_commit))
+                    # The submodule doesn't exist, probably it wasn't
+                    # removed from the .gitmodules file.
+                    continue
                 # END handle keyerror
             # END handle critical error
 
