@@ -536,10 +536,19 @@ class Remote(LazyMixin, Iterable):
             #    and: http://stackoverflow.com/a/32991784/548792
             #
             if 'Unknown subcommand: get-url' in str(ex):
-                remote_details = self.repo.git.remote("show", self.name)
-                for line in remote_details.split('\n'):
-                    if '  Push  URL:' in line:
-                        yield line.split(': ')[-1]
+                try:
+                    remote_details = self.repo.git.remote("show", self.name)
+                    for line in remote_details.split('\n'):
+                        if '  Push  URL:' in line:
+                            yield line.split(': ')[-1]
+                except GitCommandError as ex:
+                    if any(msg in str(ex) for msg in ['correct access rights', 'cannot run ssh']):
+                        # If ssh is not setup to access this repository, see issue 694
+                        remote_details = self.repo.git.config('--get-all', 'remote.%s.url' % self.name)
+                        for line in remote_details.split('\n'):
+                            yield line
+                    else:
+                        raise ex
             else:
                 raise ex
 
@@ -653,7 +662,7 @@ class Remote(LazyMixin, Iterable):
         # lines which are no progress are fetch info lines
         # this also waits for the command to finish
         # Skip some progress lines that don't provide relevant information
-        fetch_info_lines = list()
+        fetch_info_lines = []
         # Basically we want all fetch info lines which appear to be in regular form, and thus have a
         # command character. Everything else we ignore,
         cmds = set(FetchInfo._flag_map.keys())
@@ -685,6 +694,8 @@ class Remote(LazyMixin, Iterable):
             msg += "Will ignore extra progress lines or fetch head lines."
             msg %= (l_fil, l_fhi)
             log.debug(msg)
+            log.debug("info lines: " + str(fetch_info_lines))
+            log.debug("head info : " + str(fetch_head_info))
             if l_fil < l_fhi:
                 fetch_head_info = fetch_head_info[:l_fil]
             else:
