@@ -6,10 +6,7 @@
 
 import random
 import tempfile
-try:
-    from unittest import skipIf
-except ImportError:
-    from unittest2 import skipIf
+from unittest import skipIf
 
 from git import (
     RemoteProgress,
@@ -47,8 +44,8 @@ class TestRemoteProgress(RemoteProgress):
 
     def __init__(self):
         super(TestRemoteProgress, self).__init__()
-        self._seen_lines = list()
-        self._stages_per_op = dict()
+        self._seen_lines = []
+        self._stages_per_op = {}
         self._num_progress_messages = 0
 
     def _parse_progress_line(self, line):
@@ -256,9 +253,15 @@ class TestRemote(TestBase):
         self.assertEqual(tinfo.ref.commit, rtag.commit)
         self.assertTrue(tinfo.flags & tinfo.NEW_TAG)
 
-        # adjust tag commit
+        # adjust the local tag commit
         Reference.set_object(rtag, rhead.commit.parents[0].parents[0])
-        res = fetch_and_test(remote, tags=True)
+
+        # as of git 2.20 one cannot clobber local tags that have changed without
+        # specifying --force, and the test assumes you can clobber, so...
+        force = None
+        if rw_repo.git.version_info[:2] >= (2, 20):
+            force = True
+        res = fetch_and_test(remote, tags=True, force=force)
         tinfo = res[str(rtag)]
         self.assertEqual(tinfo.commit, rtag.commit)
         self.assertTrue(tinfo.flags & tinfo.TAG_UPDATE)
@@ -635,7 +638,7 @@ class TestRemote(TestBase):
 
     def test_fetch_error(self):
         rem = self.rorepo.remote('origin')
-        with self.assertRaisesRegex(GitCommandError, "Couldn't find remote ref __BAD_REF__"):
+        with self.assertRaisesRegex(GitCommandError, "[Cc]ouldn't find remote ref __BAD_REF__"):
             rem.fetch('__BAD_REF__')
 
     @with_rw_repo('0.1.6', bare=False)
